@@ -6,6 +6,10 @@ class Tuple:
     self.alias_hash = None
 
   def __getitem__(self, k):
+    if k in self.meta:
+      return self.meta[k]
+    elif k in self.values:
+      return self.values[k]
     self.maybe_build_alias_hash()
     concrete_name_to_get = self.alias_hash.get(k, None)
     concrete_name_to_get = concrete_name_to_get if concrete_name_to_get else k
